@@ -65,6 +65,14 @@
 #define LOG_DEBUG               _("debug")
 #define LOG_LEVEL_DEBUG         3
 
+#ifdef __GNUC__
+#define __no_optimize __attribute__((optimize("O0")))
+#else
+#define __no_optimize
+#endif
+
+void * __memset(void *s, int c, size_t n);
+
 typedef int (*CmdOptParser)( const int aOpt, const char *aOptArg );
 typedef void (*CmdHelpFunction)( const char *aCmd );
 
@@ -110,4 +118,7 @@ void  logGenericOptions( );
 void  logCmdHelp( const char *a_pszCmd );
 void  logCmdHelpEx( const char *a_pszCmd, char *a_pszArgs[], char *a_pszArgDescs[] );
 char *logBool( BOOL aValue );
+void  logOwnerPassCmdOption( );
+void  logNVIndexCmdOption( );
+
 #endif
