@@ -39,6 +39,7 @@
 #include <openssl/evp.h>
 #include <openssl/err.h>
 
+#include "openssl_compat.h"
 
 /*
  * Global variables
@@ -52,7 +53,7 @@ char *g_pszToken  = NULL;		// Token label to be used
 
 int       g_bAttrsValid  = FALSE;
 CK_BYTE  *g_pchSubject   = NULL;	// SUBJECT attribute value
-CK_ULONG  g_ulSubjectLen = 0;
+CK_LONG   g_subjectLen = 0;
 CK_BYTE  *g_pchId        = NULL;	// ID attribute value
 CK_ULONG  g_ulIdLen      = 0;
 CK_BYTE  *g_pchName      = NULL;	// LABEL attribute value
@@ -205,7 +206,7 @@ findExistingObjects( CK_SESSION_HANDLE   a_hSession,
 	// Set up default search attributes
 	CK_ATTRIBUTE  tDefaultAttr[]     = {
 			{ CKA_TOKEN, &bTrue, sizeof( bTrue ) },
-			{ CKA_SUBJECT, g_pchSubject, g_ulSubjectLen },
+			{ CKA_SUBJECT, g_pchSubject, g_subjectLen },
 			{ CKA_ID, g_pchId, g_ulIdLen },
 		};
 	CK_ULONG      ulDefaultAttrCount = sizeof( tDefaultAttr ) / sizeof( CK_ATTRIBUTE );
@@ -372,7 +373,7 @@ readX509Cert( const char  *a_pszFile,
 		goto out;
 	}
 
-	if ( EVP_PKEY_type( pKey->type ) != EVP_PKEY_RSA ) {
+	if ( EVP_PKEY_base_id( pKey ) != EVP_PKEY_RSA ) {
 		logError( TOKEN_RSA_KEY_ERROR );
 
 		X509_free( pX509 );
@@ -443,11 +444,11 @@ createX509CertObject( X509              *a_pX509,
 	ASN1_INTEGER *pSerialNum = NULL;
 
 	CK_BYTE  *pchIssuer      = NULL;
-	CK_ULONG  ulIssuerLen    = 0;
+	CK_LONG  issuerLen    = 0;
 	CK_BYTE  *pchSerialNum   = NULL;
-	CK_ULONG  ulSerialNumLen = 0;
+	CK_LONG  serialNumLen = 0;
 	CK_BYTE  *pchCert        = NULL;
-	CK_ULONG  ulCertLen      = 0;
+	CK_LONG  certLen      = 0;
 
 	CK_OBJECT_CLASS      clCertClass = CKO_CERTIFICATE;
 	CK_CERTIFICATE_TYPE  tCertType   = CKC_X_509;
@@ -462,7 +463,7 @@ createX509CertObject( X509              *a_pX509,
 			{ CKA_MODIFIABLE, &bTrue, sizeof( bTrue ) },
 			{ CKA_LABEL, g_pchName, g_ulNameLen },
 			{ CKA_CERTIFICATE_TYPE, &tCertType, sizeof( tCertType ) },
-			{ CKA_SUBJECT, g_pchSubject, g_ulSubjectLen },
+			{ CKA_SUBJECT, g_pchSubject, g_subjectLen },
 			{ CKA_ID, g_pchId, g_ulIdLen },
 			{ CKA_ISSUER, NULL, 0 },
 			{ CKA_SERIAL_NUMBER, NULL, 0 },
@@ -479,8 +480,8 @@ createX509CertObject( X509              *a_pX509,
 				ERR_error_string( ERR_get_error( ), NULL ) );
 		goto out;
 	}
-	ulIssuerLen = i2d_X509_NAME( pIssuer, &pchIssuer );
-	if ( ulIssuerLen < 0 ) {
+	issuerLen = i2d_X509_NAME( pIssuer, &pchIssuer );
+	if ( issuerLen < 0 ) {
 		logError( TOKEN_OPENSSL_ERROR,
 				ERR_error_string( ERR_get_error( ), NULL ) );
 		goto out;
@@ -493,16 +494,16 @@ createX509CertObject( X509              *a_pX509,
 				ERR_error_string( ERR_get_error( ), NULL ) );
 		goto out;
 	}
-	ulSerialNumLen = i2d_ASN1_INTEGER( pSerialNum, &pchSerialNum );
-	if ( ulSerialNumLen < 0 ) {
+	serialNumLen = i2d_ASN1_INTEGER( pSerialNum, &pchSerialNum );
+	if ( serialNumLen < 0 ) {
 		logError( TOKEN_OPENSSL_ERROR,
 				ERR_error_string( ERR_get_error( ), NULL ) );
 		goto out;
 	}
 
 	// Get a DER encoded format of the X509 certificate
-	ulCertLen = i2d_X509( a_pX509, &pchCert );
-	if ( ulCertLen < 0 ) {
+	certLen = i2d_X509( a_pX509, &pchCert );
+	if ( certLen < 0 ) {
 		logError( TOKEN_OPENSSL_ERROR,
 				ERR_error_string( ERR_get_error( ), NULL ) );
 		goto out;
@@ -510,11 +511,11 @@ createX509CertObject( X509              *a_pX509,
 
 	// Set the attribute values
 	tCertAttr[ 8 ].pValue = pchIssuer;
-	tCertAttr[ 8 ].ulValueLen = ulIssuerLen;
+	tCertAttr[ 8 ].ulValueLen = issuerLen;
 	tCertAttr[ 9 ].pValue = pchSerialNum;
-	tCertAttr[ 9 ].ulValueLen = ulSerialNumLen;
+	tCertAttr[ 9 ].ulValueLen = serialNumLen;
 	tCertAttr[ 10 ].pValue = pchCert;
-	tCertAttr[ 10 ].ulValueLen = ulCertLen;
+	tCertAttr[ 10 ].ulValueLen = certLen;
 
 	// Create the X509 certificate object
 	rv = createObject( a_hSession, tCertAttr, ulCertAttrCount, &hObject );
@@ -691,8 +692,11 @@ createRsaPubKeyObject( RSA               *a_pRsa,
 
 	int  rc = -1;
 
-	int  nLen = BN_num_bytes( a_pRsa->n );
-	int  eLen = BN_num_bytes( a_pRsa->e );
+	const BIGNUM *rsa_n, *rsa_e;
+	RSA_get0_key( a_pRsa, &rsa_n, &rsa_e, NULL );
+
+	int  nLen = BN_num_bytes( rsa_n );
+	int  eLen = BN_num_bytes( rsa_e );
 
 	CK_RV  rv;
 
@@ -714,7 +718,7 @@ createRsaPubKeyObject( RSA               *a_pRsa,
 			{ CKA_LABEL, g_pchName, g_ulNameLen },
 			{ CKA_KEY_TYPE, &tKeyType, sizeof( tKeyType ) },
 			{ CKA_ID, g_pchId, g_ulIdLen },
-			{ CKA_SUBJECT, g_pchSubject, g_ulSubjectLen },
+			{ CKA_SUBJECT, g_pchSubject, g_subjectLen },
 			{ CKA_ENCRYPT, &bTrue, sizeof( bTrue ) },
 			{ CKA_VERIFY, &bTrue, sizeof( bTrue ) },
 			{ CKA_VERIFY_RECOVER, &bFalse, sizeof( bFalse ) },
@@ -732,8 +736,8 @@ createRsaPubKeyObject( RSA               *a_pRsa,
 	}
 
 	// Get binary representations of the RSA key information
-	BN_bn2bin( a_pRsa->n, n );
-	BN_bn2bin( a_pRsa->e, e );
+	BN_bn2bin( rsa_n, n );
+	BN_bn2bin( rsa_e, e );
 
 	// Create the RSA public key object
 	rv = createObject( a_hSession, tAttr, ulAttrCount, a_hObject );
@@ -760,14 +764,22 @@ createRsaPrivKeyObject( RSA               *a_pRsa,
 
 	int  rc = -1;
 
-	int  nLen = BN_num_bytes( a_pRsa->n );
-	int  eLen = BN_num_bytes( a_pRsa->e );
-	int  dLen = BN_num_bytes( a_pRsa->d );
-	int  pLen = BN_num_bytes( a_pRsa->p );
-	int  qLen = BN_num_bytes( a_pRsa->q );
-	int  dmp1Len = BN_num_bytes( a_pRsa->dmp1 );
-	int  dmq1Len = BN_num_bytes( a_pRsa->dmq1 );
-	int  iqmpLen = BN_num_bytes( a_pRsa->iqmp );
+	const BIGNUM *rsa_n, *rsa_e, *rsa_d;
+	const BIGNUM *rsa_p, *rsa_q;
+	const BIGNUM *rsa_dmp1, *rsa_dmq1, *rsa_iqmp;
+
+	RSA_get0_key( a_pRsa, &rsa_n, &rsa_e, &rsa_d );
+	RSA_get0_factors( a_pRsa, &rsa_p, &rsa_q );
+	RSA_get0_crt_params( a_pRsa, &rsa_dmp1, &rsa_dmq1, &rsa_iqmp );
+
+	int  nLen = BN_num_bytes( rsa_n );
+	int  eLen = BN_num_bytes( rsa_e );
+	int  dLen = BN_num_bytes( rsa_d );
+	int  pLen = BN_num_bytes( rsa_p );
+	int  qLen = BN_num_bytes( rsa_q );
+	int  dmp1Len = BN_num_bytes( rsa_dmp1 );
+	int  dmq1Len = BN_num_bytes( rsa_dmq1 );
+	int  iqmpLen = BN_num_bytes( rsa_iqmp );
 
 	CK_RV  rv;
 
@@ -795,7 +807,7 @@ createRsaPrivKeyObject( RSA               *a_pRsa,
 			{ CKA_LABEL, g_pchName, g_ulNameLen },
 			{ CKA_KEY_TYPE, &tKeyType, sizeof( tKeyType ) },
 			{ CKA_ID, g_pchId, g_ulIdLen },
-			{ CKA_SUBJECT, g_pchSubject, g_ulSubjectLen },
+			{ CKA_SUBJECT, g_pchSubject, g_subjectLen },
 			{ CKA_SENSITIVE, &bTrue, sizeof( bTrue ) },
 			{ CKA_DECRYPT, &bTrue, sizeof( bTrue ) },
 			{ CKA_SIGN, &bTrue, sizeof( bTrue ) },
@@ -821,14 +833,14 @@ createRsaPrivKeyObject( RSA               *a_pRsa,
 	}
 
 	// Get binary representations of the RSA key information
-	BN_bn2bin( a_pRsa->n, n );
-	BN_bn2bin( a_pRsa->e, e );
-	BN_bn2bin( a_pRsa->d, d );
-	BN_bn2bin( a_pRsa->p, p );
-	BN_bn2bin( a_pRsa->q, q );
-	BN_bn2bin( a_pRsa->dmp1, dmp1 );
-	BN_bn2bin( a_pRsa->dmq1, dmq1 );
-	BN_bn2bin( a_pRsa->iqmp, iqmp );
+	BN_bn2bin( rsa_n, n );
+	BN_bn2bin( rsa_e, e );
+	BN_bn2bin( rsa_d, d );
+	BN_bn2bin( rsa_p, p );
+	BN_bn2bin( rsa_q, q );
+	BN_bn2bin( rsa_dmp1, dmp1 );
+	BN_bn2bin( rsa_dmq1, dmq1 );
+	BN_bn2bin( rsa_iqmp, iqmp );
 
 	// Create the RSA private key object
 	rv = createObject( a_hSession, tAttr, ulAttrCount, a_hObject );
@@ -973,8 +985,8 @@ getSubjectId( X509 *a_pX509 ) {
 	}
 
 	// Get the DER encoded format of the subject name
-	g_ulSubjectLen = i2d_X509_NAME( pSubject, &g_pchSubject );
-	if ( !g_ulSubjectLen < 0 ) {
+	g_subjectLen = i2d_X509_NAME( pSubject, &g_pchSubject );
+	if ( g_subjectLen < 0 ) {
 		logInfo( TOKEN_OPENSSL_ERROR,
 				ERR_error_string( ERR_get_error( ), NULL ) );
 		goto out;
